@@ -282,8 +282,8 @@ class CentralReachCore(SitesCore):
             self.browser.unselect_checkbox(f'//tr[@id="billing-grid-row-{timesheet_id}"]/td/input')
 
     def clear_location(self):
-        self.click_button_by_text("Location", "Clear location")
-        self.sync_to_all_claims("Location")
+        self.click_button_by_text("Facility", "Clear location")
+        self.sync_to_all_claims("Facility")
 
     def clear_provider_supplier(self):
         self.click_button_by_text("Provider Supplier", "Clear provider supplier")
