@@ -54,15 +54,10 @@ class QuickbooksCore(SitesCore):
                 if self.does_element_displayed('//input[@id="ius-password"]'):
                     self.browser.input_text('//input[@id="ius-password"]', self.password)
                     self.browser.click_element_when_visible('//button[@id="ius-sign-in-submit-btn"]')
-                elif self.does_element_displayed('//input[@id="iux-password-confirmation-password"]'):
-                    self.browser.input_text('//input[@id="iux-password-confirmation-password"]', self.password)
-                    self.browser.click_element_when_visible(
-                        '//button[@data-testid="passwordVerificationContinueButton"]'
-                    )
                 else:
                     self.browser.click_element_when_visible('//button[@id="ius-identifier-first-submit-btn"]')
-                    if self.does_element_displayed('//input[@id="iux-password-confirmation-password"]'):
-                        self.browser.input_text('//input[@id="iux-password-confirmation-password"]', self.password)
+                    if self.does_element_displayed('//input[@data-testid="currentPasswordInput"]'):
+                        self.browser.input_text('//input[@data-testid="currentPasswordInput"]', self.password)
                         self.browser.click_element_when_visible(
                             '//button[@data-testid="passwordVerificationContinueButton"]'
                         )
