@@ -1,8 +1,15 @@
-
-
 class GroupedRow:
-    def __init__(self, customer: str, service: str, description: str, rate: float, processing_fee: bool, manager: str,
-                 row_index_start: int, service_type: str = ''):
+    def __init__(
+        self,
+        customer: str,
+        service: str,
+        description: str,
+        rate: float,
+        processing_fee: bool,
+        manager: str,
+        row_index_start: int,
+        service_type: str = "",
+    ):
         self.customer: str = customer
         self.service: str = service
         self.description: str = description
